#!/usr/bin/env python
# -*- coding: utf-8 -*-

# py_tools_ds - A collection of geospatial data analysis tools that simplify standard
# operations when handling geospatial raster and vector data as well as projections.
#
# Copyright (C) 2016-2021
# - Daniel Scheffler (GFZ Potsdam, daniel.scheffler@gfz-potsdam.de)
# - Helmholtz Centre Potsdam - GFZ German Research Centre for Geosciences Potsdam,
#   Germany (https://www.gfz-potsdam.de/)
#
# This software was developed within the context of the GeoMultiSens project funded
# by the German Federal Ministry of Education and Research
# (project grant code: 01 IS 14 010 A-C).
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""
test_array
----------

Tests for `py_tools_ds.numeric.array` module.
"""

import unittest
import numpy as np

from py_tools_ds.numeric.array import get_array_tilebounds


class Test_get_array_tilebounds(unittest.TestCase):
    @classmethod
    def setUpClass(cls):
        cls.arr = np.random.randint(1, 10, (100, 100, 5))

    def _run_and_validate(self, tile_shape):
        tile_shape = tile_shape[0] or self.arr.shape[0], tile_shape[1] or self.arr.shape[1]

        bounds = get_array_tilebounds(self.arr.shape, tile_shape)
        (rS, rE), (cS, cE) = bounds[0]
        self.assertEqual(self.arr[rS: rE + 1, cS: cE + 1].shape[:2], tile_shape)

    def test_block_tile(self):
        self._run_and_validate(tile_shape=(10, 10))

    def test_row(self):
        self._run_and_validate(tile_shape=(1, None))

    def test_col(self):
        self._run_and_validate(tile_shape=(None, 1))

    def test_pixel(self):
        self._run_and_validate(tile_shape=(1, 1))


if __name__ == '__main__':
    unittest.main()
